@@ -1,7 +1,6 @@
 defaultControl<-function(transpirationMode = "Granier") {
   return(list(
     #For all functions
-    modifyInput = TRUE,
     fillMissingSpParams = TRUE,
     verbose = TRUE,
     subdailyResults = FALSE,
@@ -14,7 +13,7 @@ defaultControl<-function(transpirationMode = "Granier") {
     leafPhenology = TRUE,
     rockyLayerDrainage = TRUE,
     unlimitedSoilWater = FALSE,
-    plantWaterPools = FALSE,
+    rhizosphereOverlap = "total",
     unfoldingDD = 300,
     verticalLayerSize = 100,
     windMeasurementHeight = 200,
@@ -46,45 +45,44 @@ defaultControl<-function(transpirationMode = "Granier") {
     allowStarvation = TRUE,
     allowDefoliation = TRUE,
     sinkLimitation = TRUE,
-    shrubDynamics = FALSE,
+    shrubDynamics = TRUE,
     allocationStrategy = "Plant_kmax",
     nonStomatalPhotosynthesisLimitation = TRUE,
     phloemConductanceFactor = 0.2, # phloem conductance per leaf area basis (l*m-2*MPa-1*s-1)
     nonSugarConcentration = 0.25, # mol · l-1
     equilibriumOsmoticConcentration = list(leaf = 0.8, sapwood = 0.6),  # (Paljakka et al. 2017)
-    minimumRelativeSugarForGrowth = 0.5,
-    # Ogle and Pacala 2010, Tree Physiology 29, 587–605
-    respirationRates = list(leaf = 0.00260274, 
-                            sapwood = 6.849315e-05, 
-                            fineroot = 0.002054795), # g gluc · g dw -1 · day -1
-    senescenceRates = list(sapwood = 0.0001261398, # day-1 Equivalent to annual 4.5% 1-(1-0.045)^(1.0/365)
-                      fineroot = 0.001897231), #day-1 Equivalent to annual 50% 1-(1-0.5)^(1.0/365)
+    minimumRelativeStarchForGrowth = 0.50,
     constructionCosts = list(leaf = 1.5, 
                              sapwood = 1.47, 
                              fineroot = 1.30), #  g gluc · g dw -1
-    maximumRelativeGrowthRates = list(leaf = 0.01, # m2 leaf ·cm-2 sapwood· day-1
+    senescenceRates = list(sapwood = 0.0001261398, # day-1 Equivalent to annual 4.5% 1-(1-0.045)^(1.0/365)
+                      fineroot = 0.001897231), #day-1 Equivalent to annual 50% 1-(1-0.5)^(1.0/365)
+    maximumRelativeGrowthRates = list(leaf = 0.03, # m2 leaf ·cm-2 sapwood· day-1
+                                      cambium = 0.005, # cm2 sapwood ·cm-1 cambium· day-1
                                       sapwood = 0.002, # cm2 sapwood ·cm-2 sapwood· day-1
                                       fineroot = 0.1), # g dw · g dw -1 · day -1
     mortalityMode = "density/deterministic",
-    mortalityBaselineRate = 0.01,
+    mortalityBaselineRate = 0.0015,
     mortalityRelativeSugarThreshold = 0.3,
     mortalityRWCThreshold = 0.3,
     
     #dynamics
-    recruitmentMode = "deterministic",
-    removeDeadCohorts=TRUE,
+    allowRecruitment = TRUE,
+    recruitmentMode = "stochastic",
+    removeEmptyCohorts=TRUE,
     minimumCohortDensity = 1,
     seedRain = NULL,
     seedProductionTreeHeight = 300,
     seedProductionShrubHeight = 30,
+    probRecr = 0.05,
     minTempRecr	= 0,
     minMoistureRecr	= 0.3,
     minFPARRecr = 10,
-    recrTreeDBH = 1,
-    recrTreeDensity = 100,
-    recrTreeHeight = 100,
+    recrTreeDBH = 7.5,
+    recrTreeDensity = 500,
+    recrTreeHeight = 800,
     recrShrubCover = 1,
-    recrShrubHeight = 10,
+    recrShrubHeight = 25,
     recrTreeZ50 = 100,
     recrShrubZ50 = 50,
     recrTreeZ95 = 1000,
@@ -94,7 +92,6 @@ defaultControl<-function(transpirationMode = "Granier") {
     #For forest dynamics
 #     freqZopt = 20,
 #     sap2tree=TRUE,
-#     removeDeadCohorts=TRUE,
 #     initRadius = 5000,
 #     setDefaults = TRUE,
 #     diamClasses = c(0,0.5,0.75,1.0,1.5,2.0,3.0,4.0,5.0,7.5,10.0, seq(15,200, by=5)),
