@@ -35,7 +35,7 @@ summary.forest<-function(object, SpParams, mode = "MED", detailed = FALSE, ...)
   }
   summaryLAI<-function(x, SpParams) {
     ntree = nrow(x$treeData)
-    nshrub = nrow(x$treeData)
+    nshrub = nrow(x$shrubData)
     LAIc = plant_LAI(x, SpParams, mode= mode)
     LAIt = 0
     LAIsh = 0
@@ -47,6 +47,17 @@ summary.forest<-function(object, SpParams, mode = "MED", detailed = FALSE, ...)
     else return(c(LAI= (LAIt+LAIsh), LAI_trees = LAIt,
                   LAI_shrubs = LAIsh))
   }
+  summaryCover<-function(x, SpParams) {
+    ntree = nrow(x$treeData)
+    nshrub = nrow(x$shrubData)
+    coh_cov = plant_cover(x, SpParams)
+    covt = 0
+    covsh = 0
+    if(ntree>0) covt = min(100,sum(coh_cov[1:ntree], na.rm=T))
+    if(nshrub>0) covsh = min(100,sum(coh_cov[(1+ntree):(1+ntree+nshrub)], na.rm=T))
+    return(c(Tree_cover = covt,
+             Shrub_cover = covsh))
+  }
   summaryFuel<-function(x, SpParams) {
     ntree = nrow(x$treeData)
     nshrub = nrow(x$treeData)
@@ -63,19 +74,23 @@ summary.forest<-function(object, SpParams, mode = "MED", detailed = FALSE, ...)
   }
   s = c(summaryNumber(object, SpParams),
         summaryBasalArea(object, SpParams),
+        summaryCover(object, SpParams),
         summaryLAI(object,SpParams),
         summaryFuel(object,SpParams))
   s["Phytovolume"] = sum(plant_phytovolume(object, SpParams),na.rm=TRUE)
+  s["PARground"] = light_PARground(object, SpParams)
+  s["SWRground"] = light_SWRground(object, SpParams)
   class(s)<-c("summary.forest","list")
   return(s)
 }
 print.summary.forest<-function(x, digits=getOption("digits"),...) {
-  cat("Forest summary:\n\n")
-  cat(paste("  Tree density (ind/ha):", x["N"],"\n"))
-  cat(paste("  BA (m2/ha):", round(x["BA"],digits),"\n"))
-  cat(paste("  Shrub crown phytovolume (m3/m2):", round(x["Phytovolume"],digits),"\n"))
-  cat(paste("  LAI (m2/m2) total:", round(x["LAI"], digits)," trees:", round(x["LAI_trees"], digits),
+  cat(paste("Tree density (ind/ha):", x["N"],"\n"))
+  cat(paste("Tree BA (m2/ha):", round(x["BA"],digits),"\n"))
+  cat(paste("Cover (%) trees (open ground):", round(x["Tree_cover"],digits), " shrubs:", round(x["Shrub_cover"],digits),"\n"))
+  cat(paste("Shrub crown phytovolume (m3/m2):", round(x["Phytovolume"],digits),"\n"))
+  cat(paste("LAI (m2/m2) total:", round(x["LAI"], digits)," trees:", round(x["LAI_trees"], digits),
             " shrubs:", round(x["LAI_shrubs"], digits),"\n"))
-  cat(paste("  Live fine fuel (kg/m2) total:", round(x["Fuel"], digits)," trees:", round(x["Fuel_trees"], digits),
+  cat(paste("Live fine fuel (kg/m2) total:", round(x["Fuel"], digits)," trees:", round(x["Fuel_trees"], digits),
             " shrubs:", round(x["Fuel_shrubs"], digits),"\n"))
+  cat(paste("PAR ground (%):", round(x["PARground"],digits)," SWR ground (%):", round(x["SWRground"],digits),"\n"))
 }
\ No newline at end of file
